@@ -47,6 +47,11 @@ def setup(module):
         )
 
     if module == "alphafold":
+        if platform.system() == "Windows":
+            logging.warning(
+                "gget setup alphafold and gget alphafold are not supported on Windows OS."
+            )
+
         ## Make sure package paths are appended so openmm can be imported
         site_packages_path = os.__file__.split("os.py")[0] + "site-packages"
         if site_packages_path not in sys.path:
@@ -104,7 +109,7 @@ def setup(module):
             return
 
         ## Install Alphafold if not already installed
-        logging.info("Installing AlphaFold from source (requires pip).")
+        logging.info("Installing AlphaFold from source (requires pip and git).")
         # Install AlphaFold and apply OpenMM patch.
         # command = f"""
         #     git clone {ALPHAFOLD_GIT_REPO} alphafold \
@@ -202,7 +207,7 @@ def setup(module):
             sys.path.append(alphafold_path)
 
         ## Install pdbfixer v1.7 (compadible with openmm v7.5.1)
-        logging.info("Installing pdbfixer from source (requires pip).")
+        logging.info("Installing pdbfixer from source (requires pip and git).")
 
         pdbfixer_folder = os.path.join(
             PACKAGE_PATH, "tmp_pdbfixer_" + str(uuid.uuid4())
@@ -316,6 +321,7 @@ def setup(module):
                     sys.stderr.write(stderr)
             # Exit system if the subprocess returned with an error
             if process.wait() != 0:
+                logging.error("Model parameter download failed.")
                 return
             else:
                 logging.info("Model parameter download complete.")
